@@ -209,7 +209,7 @@ class Model(object):
                     all_members[k] = v
         keys = []
         for k, prop in all_members.iteritems():
-            if issubclass(prop.__class__, BaseProperty):
+            if hasattr(prop, '__class__') and issubclass(prop.__class__, BaseProperty):
                 if not prop.key:
                     prop.key = k
                 if prop.key in keys:
